<?php

add_action( 'admin_init', 'jabbadu_options_init' );
add_action( 'admin_menu', 'jabbadu_options_add_page' );

/**
 * Init plugin options to white list our options
 */
function jabbadu_options_init(){
	register_setting( 'jabbadu_options', 'jabbadu_theme_options', 'jabbadu_options_validate' );
}

/**
 * Load up the menu page
 */
function jabbadu_options_add_page() {
	add_theme_page( __( 'Theme Options', 'jabbadu' ), __( 'Theme Options', 'jabbadu' ), 'edit_theme_options', 'theme_options', 'jabbadu_options_do_page' );
}

/**
 * Create arrays for our select and radio options
 */
$select_options = array(
	'0' => array(
		'value' =>	'0',
		'label' => __( 'Standard', 'jabbadu' )
	),
	'1' => array(
		'value' =>	'1',
		'label' => __( 'Cerulean', 'jabbadu' )
	),
	'2' => array(
		'value' => '2',
		'label' => __( 'Flatly', 'jabbadu' )
	),
	'3' => array(
		'value' => '3',
		'label' => __( 'Sandstone', 'jabbadu' )
	),
	'4' => array(
		'value' => '4',
		'label' => __( 'Cosmo', 'jabbadu' )
	),
	'5' => array(
		'value' => '5',
		'label' => __( 'Journal', 'jabbadu' )
	),
	'6' => array(
		'value' => '6',
		'label' => __( 'Lumen', 'jabbadu' )
	),
	'7' => array(
		'value' => '7',
		'label' => __( 'Paper', 'jabbadu' )
	),
	'8' => array(
		'value' => '8',
		'label' => __( 'Readable', 'jabbadu' )
	),
	'9' => array(
		'value' => '9',
		'label' => __( 'Simplex', 'jabbadu' )
	),
	'10' => array(
		'value' => '10',
		'label' => __( 'Spacelab', 'jabbadu' )
	),
	'11' => array(
		'value' => '11',
		'label' => __( 'United', 'jabbadu' )
	),
	'12' => array(
		'value' => '12',
		'label' => __( 'Yeti', 'jabbadu' )
	)
);

$radio_options = array(
	'yes' => array(
		'value' => 'yes',
		'label' => __( 'Yes', 'jabbadu' )
	),
	'no' => array(
		'value' => 'no',
		'label' => __( 'No', 'jabbadu' )
	),
	'maybe' => array(
		'value' => 'maybe',
		'label' => __( 'Maybe', 'jabbadu' )
	)
);

/**
 * Create the options page
 */
function jabbadu_options_do_page() {
	global $select_options, $radio_options;

	if ( ! isset( $_REQUEST['settings-updated'] ) )
		$_REQUEST['settings-updated'] = false;

	?>
	<div class="wrap">

		<?php echo "<h2>" . wp_get_theme() . __( ' Theme Options', 'jabbadu' ) . "</h2>"; ?>

		<?php if ( false !== $_REQUEST['settings-updated'] ) : ?>
		<div class="updated fade"><p><strong><?php _e( 'Options saved', 'jabbadu' ); ?></strong></p></div>
		<?php endif; ?>

		<form method="post" action="options.php">
			<?php settings_fields( 'jabbadu_options' ); ?>
			<?php $options = get_option( 'jabbadu_theme_options' ); ?>
			
			<table style="width: 75%; float:left;" class="form-table">
				<?php
				/**
				 * A sample select input option
				 */
				?>
				<tr valign="top"><th scope="row"><?php _e( 'Choose Theme', 'jabbadu' ); ?></th>
					<td>
						<select name="jabbadu_theme_options[choosetheme]">
							<?php
								$selected = $options['choosetheme'];
								$p = '';
								$r = '';

								foreach ( $select_options as $option ) {
									$label = $option['label'];
									if ( $selected == $option['value'] ) // Make default first in list
										$p = "\n\t<option style=\"padding-right: 10px;\" selected='selected' value='" . esc_attr( $option['value'] ) . "'>$label</option>";
									else
										$r .= "\n\t<option style=\"padding-right: 10px;\" value='" . esc_attr( $option['value'] ) . "'>$label</option>";
								}
								echo $p . $r;
							?>
						</select>
						<label class="description" for="jabbadu_theme_options[choosetheme]"></label>
					</td>
				</tr>

				<?php
				/**
				 * A sample checkbox option
				 */
				?>
				<tr valign="top"><th scope="row"><?php _e( 'Navigation', 'jabbadu' ); ?></th>
					<td>
						<input id="jabbadu_theme_options[nav_style]" name="jabbadu_theme_options[nav_style]" type="checkbox" value="1" <?php checked( '1', $options['nav_style'] ); ?> />
						<label class="description" for="jabbadu_theme_options[nav_style]"><?php _e( 'Inverse Navbar', 'jabbadu' ); ?></label>
					</td>
				</tr>

				<tr valign="top"><th scope="row"><?php _e( 'Display footer paragraph', 'jabbadu' ); ?></th>
					<td>
						<input id="jabbadu_theme_options[ft_credits]" name="jabbadu_theme_options[ft_credits]" type="checkbox" value="1" <?php checked( '1', $options['ft_credits'] ); ?> />
						<label class="description" for="jabbadu_theme_options[ft_credits]"><?php _e( 'Display footer', 'jabbadu' ); ?></label>
					</td>
				</tr>

				<?php
				/**
				 * A sample text input option
				 */
				?>
				<tr valign="top"><th scope="row"><?php _e( 'Footer paragraph', 'jabbadu' ); ?></th>
					<td>
						<input id="jabbadu_theme_options[footertext]" class="regular-text" type="text" name="jabbadu_theme_options[footertext]" value="<?php esc_attr_e( $options['footertext'] ); ?>" />
						<label class="description" for="jabbadu_theme_options[footertext]"></label>
					</td>
				</tr>

				<tr valign="top"><th scope="row"><?php _e( 'Custom CSS', 'jabbadu' ); ?></th>
					<td>
						<textarea id="jabbadu_theme_options[csstextarea]" class="large-text" cols="50" rows="10" name="jabbadu_theme_options[csstextarea]"><?php echo esc_textarea( $options['csstextarea'] ); ?></textarea>
					</td>
				</tr>

			</table>
				<div style="float: right; width: 20%;">
					<h3></h3>
					<a href="http://affiliatetheme.io/r/29/" target="_blank" title="WordPress Affiliate Theme - Go Pro!"><img src="http://affiliatetheme.io/img/at-04-skyscraper-160x600.png" alt="WordPress Affiliate Theme" /></a>
				</div>
			<p class="submit">
				<input type="submit" class="button-primary" value="<?php _e( 'Save Options', 'jabbadu' ); ?>" />
			</p>

		</form>
	</div>
	<?php
}

/**
 * Sanitize and validate input. Accepts an array, return a sanitized array.
 */
function jabbadu_options_validate( $input ) {
	global $select_options, $radio_options;

	// Our checkbox value is either 0 or 1
	if ( ! isset( $input['ft_credits'] ) )
		$input['ft_credits'] = null;
	$input['ft_credits'] = ( $input['ft_credits'] == 1 ? 1 : 0 );

	// Our checkbox value is either 0 or 1
	if ( ! isset( $input['nav_style'] ) )
		$input['nav_style'] = null;
	$input['nav_style'] = ( $input['nav_style'] == 1 ? 1 : 0 );

	// Our select option must actually be in our array of select options
	if ( ! array_key_exists( $input['choosetheme'], $select_options ) )
		$input['choosetheme'] = null;

	// Our radio option must actually be in our array of radio options
	if ( ! isset( $input['radioinput'] ) )
		$input['radioinput'] = null;
	if ( ! array_key_exists( $input['radioinput'], $radio_options ) )
		$input['radioinput'] = null;

	// Say our textarea option must be safe text with the allowed tags for posts
	$input['csstextarea'] = wp_filter_post_kses( $input['csstextarea'] );

	return $input;
}

// adapted from http://planetozh.com/blog/2009/05/handling-plugins-options-in-wordpress-28-with-register_setting/

?>